@@ -1,4 +1,5 @@
 const gchar* documentation_credits[] = {
+	"Brent Smith <gnome@nextreality.net>",
 	"Shaun McCance <shaunm@gnome.org>",
 	NULL
 };
@@ -97,6 +98,11 @@ const gchar* documentation_credits[] = {
 #define HELP_GNOME_DOC_XSLT_TEMPLATE_DB_HTML_SUBTITLE_HEADER "template_db2html.subtitle.header"
 #define HELP_GNOME_DOC_XSLT_SECTION_DB_HTML_XREF "section-db2html-xref"
 #define HELP_GNOME_DOC_XSLT_TEMPLATE_DB_HTML_ANCHOR "template_db2html.anchor"
+#define HELP_GNOME_DOC_XSLT_SECTION_DB_HTML_FOOTNOTE "section-db2html-footnote"
+#define HELP_GNOME_DOC_XSLT_TEMPLATE_DB_HTML_FOOTNOTE_REF "template_db2html.footnote.ref"
+#define HELP_GNOME_DOC_XSLT_TEMPLATE_DB_HTML_FOOTNOTE_NOTE "template_db2html.footnote.note"
+#define HELP_GNOME_DOC_XSLT_TEMPLATE_DB_HTML_FOOTNOTE_FOOTER "template_db2html.footnote.footer"
+#define HELP_GNOME_DOC_XSLT_TEMPLATE_DB_HTML_FOOTNOTE_CSS "template_db2html.footnote.css"
 #define HELP_GNOME_DOC_XSLT_SECTION_DB_CHUNK "section-db-chunk"
 #define HELP_GNOME_DOC_XSLT_PARAM_DB_CHUNK_CHUNKS "param_db.chunk.chunks"
 #define HELP_GNOME_DOC_XSLT_PARAM_DB_CHUNK_CHUNK_TOP "param_db.chunk.chunk_top"
@@ -162,6 +168,7 @@ const gchar* documentation_credits[] = {
 #define HELP_GNOME_DOC_XSLT_PARAM_L__N_CHARSET "param_l10n.charset"
 #define HELP_GNOME_DOC_XSLT_TEMPLATE_L__N_GETTEXT "template_l10n.gettext"
 #define HELP_GNOME_DOC_XSLT_TEMPLATE_L__N_PLURAL_FORM "template_l10n.plural.form"
+#define HELP_GNOME_DOC_XSLT_TEMPLATE_L__N_DIRECTION "template_l10n.direction"
 #define HELP_GNOME_DOC_XSLT_TEMPLATE_L__N_LANGUAGE "template_l10n.language"
 #define HELP_GNOME_DOC_XSLT_TEMPLATE_L__N_REGION "template_l10n.region"
 #define HELP_GNOME_DOC_XSLT_TEMPLATE_L__N_VARIANT "template_l10n.variant"
@@ -180,6 +187,9 @@ const gchar* documentation_credits[] = {
 
 #define HELP_GNOME_DOC_MAKE_INDEX "index"
 #define HELP_GNOME_DOC_MAKE_LEGALNOTICE "legalnotice"
-#define HELP_GNOME_DOC_MAKE_INTRO "intro"
+#define HELP_GNOME_DOC_MAKE_EXAMPLE_OMF_TEMPLATE "example-omf-template"
+#define HELP_GNOME_DOC_MAKE_SETTINGUP_DOCUMENT_NAME_XML "settingup-document-name.xml"
+#define HELP_GNOME_DOC_MAKE_EXAMPLE_OMF_DOCBOOK "example-omf-docbook"
+#define HELP_GNOME_DOC_MAKE_EXAMPLE_OMF_AUTOGEN "example-omf-autogen"
 #define HELP_GNOME_DOC_MAKE_REFERENCE "reference"
 
